aboutsummaryrefslogtreecommitdiffstats
path: root/googlemock/include/gmock/gmock-actions.h
diff options
context:
space:
mode:
authorRyan Yee <ryee88@gmail.com>2018-10-11 01:22:25 -0700
committerGitHub <noreply@github.com>2018-10-11 01:22:25 -0700
commit4d50ab75a730a9aa237a076ddd1a5d4f9f3aadff (patch)
tree66405faeaa2a21dc705862d9b77672e0888dff54 /googlemock/include/gmock/gmock-actions.h
parenta83429f5d31ad7c48bb0493475f8a77450f03311 (diff)
parent658c6390a5b363f46c6ad448ad1bce9d6e97e53a (diff)
downloadgoogletest-4d50ab75a730a9aa237a076ddd1a5d4f9f3aadff.tar.gz
googletest-4d50ab75a730a9aa237a076ddd1a5d4f9f3aadff.tar.bz2
googletest-4d50ab75a730a9aa237a076ddd1a5d4f9f3aadff.zip
Merge branch 'master' into typo
Diffstat (limited to 'googlemock/include/gmock/gmock-actions.h')
-rw-r--r--googlemock/include/gmock/gmock-actions.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/googlemock/include/gmock/gmock-actions.h b/googlemock/include/gmock/gmock-actions.h
index e3b3f094..8e7e0e7b 100644
--- a/googlemock/include/gmock/gmock-actions.h
+++ b/googlemock/include/gmock/gmock-actions.h
@@ -439,7 +439,7 @@ class Action {
// template <typename Result, typename ArgumentTuple>
// Result Perform(const ArgumentTuple& args) const {
// // Processes the arguments and returns a result, using
// // tr1::get<N>(args) to get the N-th (0-based) argument in the tuple.
// }
// ...
// };
@@ -838,7 +838,7 @@ class SetArgumentPointeeAction {
template <typename Result, typename ArgumentTuple>
void Perform(const ArgumentTuple& args) const {
CompileAssertTypesEqual<void, Result>();
- *::testing::get<N>(args) = value_;
+ *::std::get<N>(args) = value_;
}
private:
@@ -861,7 +861,7 @@ class SetArgumentPointeeAction<N, Proto, true> {
template <typename Result, typename ArgumentTuple>
void Perform(const ArgumentTuple& args) const {
CompileAssertTypesEqual<void, Result>();
- ::testing::get<N>(args)->CopyFrom(*proto_);
+ ::std::get<N>(args)->CopyFrom(*proto_);
}
private:
@@ -439,7 +439,7 @@ class Action {
// Result Perform(const ArgumentTuple& args) const {
// // Processes the arguments and returns a result, using
-// // tr1::get<N>(args) to get the N-th (0-based) argument in the tuple.
+// // std::get<N>(args) to get the N-th (0-based) argument in the tuple.
// }
// ...